@@ -3,6 +3,7 @@ CREATE SEQUENCE ir_configuration_id_seq;
 CREATE TABLE ir_configuration (
     id INTEGER DEFAULT NEXTVAL('ir_configuration_id_seq') NOT NULL,
     language VARCHAR,
+    hostname VARCHAR,
     PRIMARY KEY(id)
 );
 
@@ -78,6 +79,7 @@ CREATE TABLE ir_lang (
     name VARCHAR NOT NULL,
     code VARCHAR NOT NULL,
     translatable BOOLEAN NOT NULL,
+    parent VARCHAR,
     active BOOLEAN NOT NULL,
     direction VARCHAR NOT NULL,
     PRIMARY KEY(id)
@@ -89,12 +91,12 @@ CREATE TABLE res_user (
     id INTEGER DEFAULT NEXTVAL('res_user_id_seq') NOT NULL,
     name VARCHAR NOT NULL,
     active BOOLEAN NOT NULL,
-    login VARCHAR NOT NULL UNIQUE,
+    login VARCHAR NOT NULL,
     password VARCHAR,
     PRIMARY KEY(id)
 );
 
-ALTER TABLE res_user ADD CONSTRAINT res_user_login_uniq UNIQUE (login);
+ALTER TABLE res_user ADD CONSTRAINT res_user_login_key UNIQUE (login);
 
 INSERT INTO res_user (id, login, password, name, active) VALUES (0, 'root', NULL, 'Root', False);
 
@@ -117,10 +119,10 @@ CREATE TABLE "res_user-res_group" (
     PRIMARY KEY(id)
 );
 
-CREATE SEQUENCE ir_module_module_id_seq;
+CREATE SEQUENCE ir_module_id_seq;
 
-CREATE TABLE ir_module_module (
-    id INTEGER DEFAULT NEXTVAL('ir_module_module_id_seq') NOT NULL,
+CREATE TABLE ir_module (
+    id INTEGER DEFAULT NEXTVAL('ir_module_id_seq') NOT NULL,
     create_uid INTEGER NOT NULL,
     create_date TIMESTAMP WITHOUT TIME ZONE NOT NULL,
     write_date TIMESTAMP WITHOUT TIME ZONE,
@@ -132,12 +134,12 @@ CREATE TABLE ir_module_module (
     FOREIGN KEY (write_uid) REFERENCES res_user ON DELETE SET NULL
 );
 
-ALTER TABLE ir_module_module ADD CONSTRAINT name_uniq UNIQUE (name);
+ALTER TABLE ir_module ADD CONSTRAINT ir_module_name_uniq UNIQUE (name);
 
-CREATE SEQUENCE ir_module_module_dependency_id_seq;
+CREATE SEQUENCE ir_module_dependency_id_seq;
 
-CREATE TABLE ir_module_module_dependency (
-    id INTEGER DEFAULT NEXTVAL('ir_module_module_dependency_id_seq') NOT NULL,
+CREATE TABLE ir_module_dependency (
+    id INTEGER DEFAULT NEXTVAL('ir_module_dependency_id_seq') NOT NULL,
     create_uid INTEGER NOT NULL,
     create_date TIMESTAMP WITHOUT TIME ZONE NOT NULL,
     write_date TIMESTAMP WITHOUT TIME ZONE,
@@ -147,5 +149,13 @@ CREATE TABLE ir_module_module_dependency (
     PRIMARY KEY(id),
     FOREIGN KEY (create_uid) REFERENCES res_user ON DELETE SET NULL,
     FOREIGN KEY (write_uid) REFERENCES res_user ON DELETE SET NULL,
-    FOREIGN KEY (module) REFERENCES ir_module_module ON DELETE CASCADE
+    FOREIGN KEY (module) REFERENCES ir_module ON DELETE CASCADE
+);
+
+CREATE SEQUENCE ir_cache_id_seq;
+
+CREATE TABLE ir_cache (
+    id INTEGER DEFAULT NEXTVAL('ir_cache_id_seq') NOT NULL,
+    name VARCHAR NOT NULL,
+    "timestamp" TIMESTAMP WITHOUT TIME ZONE
 );
