@@ -35,7 +35,9 @@ class BaseCache(object):
 
     def _key(self, key):
         if self.context:
-            return (key, Transaction().user, freeze(Transaction().context))
+            context = Transaction().context
+            context.pop('client', None)
+            return (key, Transaction().user, freeze(context))
         return key
 
     def get(self, key, default=None):
