@@ -208,6 +208,13 @@ class ModelView(Model):
                 cls.__rpc__.setdefault(button,
                     RPC(instantiate=0, result=on_change_result))
 
+            for parent_cls in cls.__mro__:
+                parent_meth = getattr(parent_cls, button, None)
+                if not parent_meth:
+                    continue
+                cls.__change_buttons[button] |= getattr(
+                    parent_meth, 'change', set())
+
     @classmethod
     def fields_view_get(cls, view_id=None, view_type='form'):
         '''
@@ -748,16 +755,17 @@ class ModelView(Model):
                         value = value.id
             elif field._type == 'one2many':
                 targets = value
-                init_targets = list(init_values.get(fname, []))
+                init_targets = list(init_values.get(fname, targets))
                 value = collections.defaultdict(list)
                 value['remove'] = [t.id for t in init_targets if t.id]
                 for i, target in enumerate(targets):
                     if target.id in value['remove']:
                         value['remove'].remove(target.id)
-                        target_changed = target._changed_values
-                        if target_changed:
-                            target_changed['id'] = target.id
-                            value['update'].append(target_changed)
+                        if isinstance(target, ModelView):
+                            target_changed = target._changed_values
+                            if target_changed:
+                                target_changed['id'] = target.id
+                                value['update'].append(target_changed)
                     else:
                         if isinstance(target, ModelView):
                             # Ensure initial values are returned because target
